Enum BuildError
pub enum BuildError {
FailedToCreateRuntime(String),
FailedToCreateHTTPListener(String),
FailedToSetGlobalRecorder(SetRecorderError<PrometheusRecorder>),
InvalidAllowlistAddress(String),
InvalidPushGatewayEndpoint(String),
MissingExporterConfiguration,
EmptyBucketsOrQuantiles,
ZeroBucketDuration,
}Expand description
Errors that could occur while building or installing a Prometheus recorder/exporter.
Variants
FailedToCreateRuntime(String)
There was an issue when creating the necessary Tokio runtime to launch the exporter.
FailedToCreateHTTPListener(String)
There was an issue when creating the HTTP listener.
FailedToSetGlobalRecorder(SetRecorderError<PrometheusRecorder>)
Installing the recorder did not succeed.
InvalidAllowlistAddress(String)
The given address could not be parsed successfully as an IP address/subnet.
InvalidPushGatewayEndpoint(String)
The given push gateway endpoint is not a valid URI.
MissingExporterConfiguration
No exporter configuration was present.
This generally only occurs when HTTP listener support is disabled, but no push gateway configuration was give to the builder.
EmptyBucketsOrQuantiles
Bucket bounds or quantiles were empty.
ZeroBucketDuration
Bucket duration cannot be zero.