Enum Distribution
pub enum Distribution {
Histogram(Histogram),
Summary(RollingSummary, Arc<Vec<Quantile>>, f64),
NativeHistogram(NativeHistogram),
}Expand description
Distribution type.
Variants
Histogram(Histogram)
A Prometheus histogram.
Exposes “bucketed” values to Prometheus, counting the number of samples below a given threshold i.e. 100 requests faster than 20ms, 1000 requests faster than 50ms, etc.
Summary(RollingSummary, Arc<Vec<Quantile>>, f64)
A Prometheus summary.
Computes and exposes value quantiles directly to Prometheus i.e. 50% of requests were faster than 200ms, and 99% of requests were faster than 1000ms, etc.
NativeHistogram(NativeHistogram)
A Prometheus native histogram.
Uses exponential buckets to efficiently represent histogram data without requiring predefined bucket boundaries.
Implementations
impl Distribution
impl Distribution
pub fn new_histogram(buckets: &[f64]) -> Distribution
pub fn new_histogram(buckets: &[f64]) -> Distribution
pub fn new_summary(
quantiles: Arc<Vec<Quantile>>,
bucket_duration: Duration,
bucket_count: NonZero<u32>,
) -> Distribution
pub fn new_summary( quantiles: Arc<Vec<Quantile>>, bucket_duration: Duration, bucket_count: NonZero<u32>, ) -> Distribution
Creates a summary distribution.
pub fn new_native_histogram(config: NativeHistogramConfig) -> Distribution
pub fn new_native_histogram(config: NativeHistogramConfig) -> Distribution
Creates a native histogram distribution.
pub fn record_samples(&mut self, samples: &[(f64, Instant)])
pub fn record_samples(&mut self, samples: &[(f64, Instant)])
Records the given samples in the current distribution.