pub struct PrometheusRecorder { /* private fields */ }Expand description
A handle to the Prometheus recorder.
This is intended to be used as the global recorder.
Callers must ensure that PrometheusRecorder::spawn_upkeep is called once.
Implementations
Sourceimpl PrometheusRecorder
impl PrometheusRecorder
Sourcepub const fn handle(&self) -> &PrometheusHandle
pub const fn handle(&self) -> &PrometheusHandle
Returns a reference to the PrometheusHandle.
Sourcepub fn spawn_upkeep(&self)
pub fn spawn_upkeep(&self)
Spawns the upkeep task if there hasn’t been one spawned already.
Panics
This method must be called from within an existing Tokio runtime or it will panic.
See also PrometheusHandle::run_upkeep
Sourcepub fn install() -> Result<Self>
pub fn install() -> Result<Self>
Installs Prometheus as the metrics recorder.
Caution: This only configures the global recorder and does not spawn the exporter.
Callers must run Self::spawn_upkeep manually.
Sourcepub fn install_with_builder(builder: PrometheusBuilder) -> Result<Self>
pub fn install_with_builder(builder: PrometheusBuilder) -> Result<Self>
Installs Prometheus as the metrics recorder with a custom builder.
Caution: This only configures the global recorder and does not spawn the exporter.
Callers must run Self::spawn_upkeep manually.