Struct PrometheusHandle
pub struct PrometheusHandle { /* private fields */ }Expand description
Handle for accessing metrics stored via PrometheusRecorder.
In certain scenarios, it may be necessary to directly handle requests that would otherwise be
handled directly by the HTTP listener, or push gateway background task. PrometheusHandle
allows rendering a snapshot of the current metrics stored by an installed PrometheusRecorder
as a payload conforming to the Prometheus exposition format.
Implementations
impl PrometheusHandle
impl PrometheusHandle
pub fn render(&self) -> String
pub fn render(&self) -> String
Takes a snapshot of the metrics held by the recorder and generates a payload conforming to the Prometheus exposition format.
pub fn render_to_write(&self, output: &mut impl Write) -> Result<(), Error>
pub fn render_to_write(&self, output: &mut impl Write) -> Result<(), Error>
Takes a snapshot of the metrics held by the recorder and generates a payload conforming to the Prometheus exposition format, incrementally. Use this function to emit metrics as a stream without buffering the entire metrics export.
Errors
Writing to the provided output fails.
pub fn run_upkeep(&self)
pub fn run_upkeep(&self)
Performs upkeeping operations to ensure metrics held by recorder are up-to-date and do not grow unboundedly.